# pyCallisto

pyCallisto is a image processing and data analysis python library developed for e-CALLISTO data (http://www.e-callisto.org/). However, this library could be used to process the data obtained using various solar radio spectrometers available around the globe.

# Installation

At present, you can use this library by copying the source files (pyCallisto.py and pyCallistoUtils.py) to a local folder. The data and main program have to located in the same folder. In the main program you have to import the source files as shown in sample_program.py. 

# Pre-requisites and Standard Python Libraries 

    python 3.6,
    numpy,
    matplotlib,
    astropy.

# Contributors

    Mr. Ravindra Pawase, 
    Team Lead (Machine Learning), 
    Persistent Systems, 
    Pune-411 004, India.
    
    Dr. K. Sasikumar Raja, 
    National Post Doctoral Fellow, 
    Deparment of Physics, 
    Indian Institute of Science Education and Research, 
    Dr. Homi Bhabha Road, Pashan, Pune-411 008, India.

# Feedback

If you have any feedback, queries, feature request you can drop a line at

    ravi.pawase@gmail.com
    sasikumarraja@gmail.com

# Citation

If you find pyCallisto useful and make use of it in your work, we appreciate acknowledging the same. We recommend using the following line: "This work is made use of the pyCallisto library, which is available at https://github.com/ravipawase/pyCallisto"

